diff --git a/core/modules/node/lib/Drupal/node/Plugin/views/argument/Nid.php b/core/modules/node/lib/Drupal/node/Plugin/views/argument/Nid.php
index 4519778..ca7aa8c 100644
--- a/core/modules/node/lib/Drupal/node/Plugin/views/argument/Nid.php
+++ b/core/modules/node/lib/Drupal/node/Plugin/views/argument/Nid.php
@@ -20,7 +20,7 @@ class Nid extends Numeric {
   /**
    * Override the behavior of title(). Get the title of the node.
    */
-  function title_query() {
+  public function titleQuery() {
     $titles = array();
 
     $nodes = node_load_multiple($this->value);
diff --git a/core/modules/node/lib/Drupal/node/Plugin/views/argument/Vid.php b/core/modules/node/lib/Drupal/node/Plugin/views/argument/Vid.php
index eb2565b..f61dd75 100644
--- a/core/modules/node/lib/Drupal/node/Plugin/views/argument/Vid.php
+++ b/core/modules/node/lib/Drupal/node/Plugin/views/argument/Vid.php
@@ -22,7 +22,7 @@ class Vid extends Numeric {
   /**
    * Override the behavior of title(). Get the title of the revision.
    */
-  function title_query() {
+  public function titleQuery() {
     $titles = array();
 
     $results = db_select('node_field_revision', 'npr')
diff --git a/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/argument/IndexTid.php b/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/argument/IndexTid.php
index f51a5ce..7197560 100644
--- a/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/argument/IndexTid.php
+++ b/core/modules/taxonomy/lib/Drupal/taxonomy/Plugin/views/argument/IndexTid.php
@@ -43,7 +43,7 @@ function set_breadcrumb(&$breadcrumb) {
     return views_taxonomy_set_breadcrumb($breadcrumb, $this);
   }
 
-  function title_query() {
+  public function titleQuery() {
     $titles = array();
     $result = db_select('taxonomy_term_data', 'td')
       ->fields('td', array('name'))
diff --git a/core/modules/user/lib/Drupal/user/Plugin/views/argument/RolesRid.php b/core/modules/user/lib/Drupal/user/Plugin/views/argument/RolesRid.php
index bbef57e..6a878ea 100644
--- a/core/modules/user/lib/Drupal/user/Plugin/views/argument/RolesRid.php
+++ b/core/modules/user/lib/Drupal/user/Plugin/views/argument/RolesRid.php
@@ -19,7 +19,7 @@
  */
 class RolesRid extends ManyToOne {
 
-  function title_query() {
+  public function titleQuery() {
     return array(entity_load('user_role', $this->value)->label());
   }
 
diff --git a/core/modules/user/lib/Drupal/user/Plugin/views/argument/Uid.php b/core/modules/user/lib/Drupal/user/Plugin/views/argument/Uid.php
index 82c5b75..5bd0bff 100644
--- a/core/modules/user/lib/Drupal/user/Plugin/views/argument/Uid.php
+++ b/core/modules/user/lib/Drupal/user/Plugin/views/argument/Uid.php
@@ -25,7 +25,7 @@ class Uid extends Numeric {
    * @return array
    *    A list of usernames.
    */
-  function title_query() {
+  public function titleQuery() {
     if (!$this->argument) {
       return array(config('user.settings')->get('anonymous'));
     }
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/argument/ManyToOne.php b/core/modules/views/lib/Drupal/views/Plugin/views/argument/ManyToOne.php
index 2cb77e0..0f5a07e 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/argument/ManyToOne.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/argument/ManyToOne.php
@@ -158,7 +158,7 @@ function title() {
       return !empty($this->definition['invalid input']) ? $this->definition['invalid input'] : t('Invalid input');
     }
 
-    return implode($this->operator == 'or' ? ' + ' : ', ', $this->title_query());
+    return implode($this->operator == 'or' ? ' + ' : ', ', $this->titleQuery());
   }
 
   function summary_query() {
@@ -196,7 +196,7 @@ function summary_argument($data) {
   /**
    * Override for specific title lookups.
    */
-  function title_query() {
+  public function titleQuery() {
     return $this->value;
   }
 
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/argument/Numeric.php b/core/modules/views/lib/Drupal/views/Plugin/views/argument/Numeric.php
index d9453d1..0e433d7 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/argument/Numeric.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/argument/Numeric.php
@@ -82,7 +82,7 @@ function title() {
       return !empty($this->definition['invalid input']) ? $this->definition['invalid input'] : t('Invalid input');
     }
 
-    return implode($this->operator == 'or' ? ' + ' : ', ', $this->title_query());
+    return implode($this->operator == 'or' ? ' + ' : ', ', $this->titleQuery());
   }
 
   /**
@@ -90,7 +90,7 @@ function title() {
    * @return array
    *    Returns all titles, if it's just one title it's an array with one entry.
    */
-  function title_query() {
+  public function titleQuery() {
     return $this->value;
   }
 
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/argument/String.php b/core/modules/views/lib/Drupal/views/Plugin/views/argument/String.php
index ccb4d54..ce22e1a 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/argument/String.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/argument/String.php
@@ -278,13 +278,13 @@ function title() {
       return !empty($this->definition['invalid input']) ? $this->definition['invalid input'] : t('Invalid input');
     }
 
-    return implode($this->operator == 'or' ? ' + ' : ', ', $this->title_query());
+    return implode($this->operator == 'or' ? ' + ' : ', ', $this->titleQuery());
   }
 
   /**
    * Override for specific title lookups.
    */
-  function title_query() {
+  public function titleQuery() {
     return drupal_map_assoc($this->value, 'check_plain');
   }
 

diff --git a/core/modules/file/lib/Drupal/file/Plugin/views/argument/Fid.php b/core/modules/file/lib/Drupal/file/Plugin/views/argument/Fid.php
index d0fb508..6906e01 100644
--- a/core/modules/file/lib/Drupal/file/Plugin/views/argument/Fid.php
+++ b/core/modules/file/lib/Drupal/file/Plugin/views/argument/Fid.php
@@ -20,9 +20,9 @@
 class Fid extends Numeric {
 
   /**
    * Override the behavior of title_query(). Get the filenames.
    */
-  function title_query() {
+  public function titleQuery() {
     $titles = db_select('file_managed', 'f')
       ->fields('f', array('filename'))
       ->condition('fid', $this->value)
@@ -20,9 +20,9 @@
 
   /**
-   * Override the behavior of title_query(). Get the filenames.
+   * Override the behavior of titleQuery(). Get the filenames.
    */